#include <cmath>
#include <cstdio>
#include <cassert>
#include <string>
#include <vector>
#include <queue>
#include <algorithm>
#include <utility>
#include <map>
#define EPS 1e-12
using namespace std;

struct pt
{
	pt() { pt(0, 0); }
	pt(double x, double y) : x(x), y(y) { }
	double x, y;
};

double ccw(pt p1, pt p2, pt p3)
{
	return (p2.x - p1.x)*(p3.y - p1.y) - (p2.y - p1.y)*(p3.x - p1.x);
}

int sign(double a)
{
	if(fabs(a) - EPS < 0)
		return 0;
	return a > 0;
}

bool isInRectangle(pt check, pt pt1, pt pt2, pt pt3, pt pt4)
{
	double c1,c2,c3,c4;
	c1 = ccw(pt1, pt2, check);
	c2 = ccw(pt2, pt3, check);
	if(sign(c1) != sign(c2))
		return false;
	c3 = ccw(pt3, pt4, check);
	if(sign(c2) != sign(c3))
		return false;
	c4 = ccw(pt4, pt1, check);
	if(sign(c3) != sign(c4))
		return false;
	return true;
}

inline bool isInRect(pt check, pt a, pt b)
{
	if(a.x < b.x) // low left - up right
		return isInRectangle(check, a, pt(b.x, a.y), b, pt(a.x, b.y));
	else 
		return isInRectangle(check, pt(a.x, b.y), b, pt(b.x, a.y), a); 
}

int main()
{
	//freopen("in.txt", "r", stdin);
	int R, P;
	scanf("%d%d", &R, &P);
	vector<pair<pt, pt> > O;
	pt a, b, check, c, d;

	for(int i = 0; i < R; i++)
	{
		scanf("%lf%lf%lf%lf", &a.x, &a.y, &b.x, &b.y);
		O.push_back(make_pair(a, b));
	}
	int cnt = 0;
	for(int i = 0; i < P; i++)
	{
		scanf("%lf%lf", &check.x, &check.y);
		for(int j = 0; j < R; j++)
		{
			if(isInRect(check, O[j].first, O[j].second))
			{
				cnt++;
				break;
			}
		}
	}
	printf("%d\n", cnt);
	return 0;
}