using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.IO;

namespace _3.Shepherd
{
	static class ExamExtensions
	{
		public static bool Debugging
		{
			get
			{
#if DEBUG
				return true;
#else
				return false;
#endif
			}
		}

		public static int ToInt32(this string s)
		{
			return Convert.ToInt32(s);
		}

		public static double ToDouble(this string s)
		{
			return Convert.ToDouble(s);
		}
	}
	
	class Point
	{
		public double X { get; set; }
		public double Y { get; set; }

		public Point() :
			this(0, 0)
		{

		}

		public Point(double x, double y)
		{
			X = x;
			Y = y;
		}

		public override string ToString()
		{
			return X + ":" + Y;
		}
	}

	class Fence
	{
		private double leftBorder;
		private double rightBorder;
		private double upperBorder;
		private double lowerBorder;

		public Fence(Point corner1, Point corner2)
		{
			leftBorder = Math.Min(corner1.X, corner2.X);
			rightBorder = Math.Max(corner1.X, corner2.X);
			lowerBorder = Math.Min(corner1.Y, corner2.Y);
			upperBorder = Math.Max(corner1.Y, corner2.Y);
		}

		public bool ContainsPointExclusive(Point p)
		{
			return leftBorder < p.X && p.X < rightBorder &&
				lowerBorder < p.Y && p.Y < upperBorder;
		}

		public override string ToString()
		{
			return leftBorder + ":" + upperBorder + ":" + rightBorder + ":" + lowerBorder;
		}
	}

	class Program
	{
		static List<Fence> fences;
		static List<Point> herd;

		static IEnumerable<string> GetInputAndAllocate()
		{
			System.Threading.Thread.CurrentThread.CurrentCulture = System.Globalization.CultureInfo.InvariantCulture;
			List<string> result = new List<string>();
			if (ExamExtensions.Debugging)
			{
				StreamReader inputFile = new StreamReader("testinput3.txt");
				string input = inputFile.ReadLine();
				string[] objectParams = input.Split(' ');
				fences = new List<Fence>(objectParams[0].ToInt32());
				herd = new List<Point>(objectParams[1].ToInt32());
				int nLinesToRead = fences.Capacity + herd.Capacity;
				for (int i = 0; i < nLinesToRead -1; i++)
				{
					result.Add(inputFile.ReadLine());
				}
			}
			else
			{
				string input = Console.ReadLine();
				string[] objectParams = input.Split(' ');
				fences = new List<Fence>(objectParams[0].ToInt32());
				herd = new List<Point>(objectParams[1].ToInt32());
				int nLinesToRead = fences.Capacity + herd.Capacity;
				for (int i = 0; i < nLinesToRead - 1; i++)
				{
					result.Add(Console.ReadLine());
				}
			}
			return result;
		}

		static void InitializeObjects(IEnumerable<string> input)
		{
			int fencesCount = 0;
			int objectsToAdd = fences.Capacity + herd.Capacity;
			foreach (string s in input)
			{
				if (fencesCount < fences.Capacity)
				{
					string[] fenceData = s.Split(' ');
					Point[] coords = new Point[] { new Point(fenceData[0].ToDouble(), fenceData[1].ToDouble()), new Point(fenceData[2].ToDouble(), fenceData[3].ToDouble()) };
					fences.Add(new Fence(coords[0], coords[1]));
					fencesCount++;
				}
				else
				{
					string[] sheepData = s.Split(' ');
					herd.Add(new Point(sheepData[0].ToDouble(), sheepData[1].ToDouble()));
				}
			}
		}

		static void Main(string[] args)
		{
			IEnumerable<string> inputData = GetInputAndAllocate();
			InitializeObjects(inputData);
			int remainingSheep = 0;
			foreach (Fence f in fences)
			{
				foreach (Point sheep in herd)
				{
					if (f.ContainsPointExclusive(sheep))
					{
						remainingSheep++;
					}
				}
			}
			Console.WriteLine(remainingSheep);
		}
	}
}
