    using System;
    using System.Diagnostics;
    using System.Collections.Generic;
    using System.Text;
     
    namespace _2_Segmented_Digits
    {
            static class DebugUtils
            {
                    private static Stopwatch performanceAnalyzer;
     
                    public static bool DebugConfigurationActive
                    {
                            get
                            {
                            #if DEBUG
                                    return true;
                            #else
                                    return false;
                            #endif
                            }
                    }
     
                    [Conditional("DEBUG")]
                    public static void StartPerformanceDiagnostic()
                    {
                            if (performanceAnalyzer == null)
                            {
                                    performanceAnalyzer = new Stopwatch();
                            }
     
                            performanceAnalyzer.Start();
                    }
     
                    [Conditional("DEBUG")]
                    public static void PrintPerformanceInfo()
                    {
                            if (performanceAnalyzer != null)
                            {
                                    Console.WriteLine("Time elapsed: {0} ms", performanceAnalyzer.Elapsed.TotalMilliseconds);
                            }
                    }
     
                    [Conditional("DEBUG")]
                    public static void StopDiagnostic()
                    {
                            if (performanceAnalyzer != null)
                            {
                                    performanceAnalyzer.Stop();
                            }
                    }
     
                    [Conditional("DEBUG")]
                    public static void PrintPeakMemoryUsage()
                    {
                            Console.WriteLine("Memory used: {0} KB", Process.GetCurrentProcess().PeakWorkingSet64 >> 10);
                    }
            }
     
            class Program
            {
                    static int[] digitsSegmentsTable = { 126, 48, 109, 121, 51, 91, 95, 112, 127, 123 };
                    static List<int[]> possibleClockFaceDigits;
                    static int[] currentCombination;
                    static int nCombinations = 0;
                    static StringBuilder consoleBuffer = new StringBuilder(10000);
                   
                    static string[] GetInput()
                    {
                            if (DebugUtils.DebugConfigurationActive)
                            {
                                    return new string[] { "1111110", "1111111" };
                            }
                            else
                            {
                                    int nLines = Convert.ToInt32(Console.ReadLine());
                                    string[] input = new string[nLines];
                                    for (int i = 0; i < nLines; i++)
                                    {
                                            input[i] = Console.ReadLine();
                                    }
                                    return input;
                            }
                    }
     
                    public static int GetSumOfInputString(string s)
                    {
                            int sum = 0;
                            for (int i = 0; i < 7; i++)
                            {
                                    if (s[s.Length - i - 1] != '0')
                                    {
                                            sum += 1 << i;
                                    }
                            }
     
                            return sum;
                    }
     
                    public static int[] GetDigitCombinations(string state)
                    {
                            List<int> result = new List<int>(8);
                            int stringSum = GetSumOfInputString(state);
                            for (int i = 0; i < digitsSegmentsTable.Length; i++)
                            {
                                    if ((digitsSegmentsTable[i] & stringSum) == stringSum)
                                    {
                                            result.Add(i);
                                    }
                            }
                            return result.ToArray();
                    }
     
                    static string CombinationSetToString(List<int> combination)
                    {
                            StringBuilder buffer = new StringBuilder(combination.Count);
                            for (int i = 0; i < combination.Count; i++)
                            {
                                    buffer.Append(combination[i]);
                            }
                            return buffer.ToString();
                    }
     
                    static void EnumerateCombinations(int currentSet)
                    {
                            if (currentSet >= currentCombination.Length)
                            {
                                    EnqueueToBuffer();
                                    nCombinations++;
                            }
                            else
                            {
                                    for (int i = 0; i < possibleClockFaceDigits[currentSet].Length; i++)
                                    {
                                            currentCombination[currentSet] = possibleClockFaceDigits[currentSet][i];
                                            EnumerateCombinations(currentSet + 1);
                                    }
                            }
                    }
     
                    static void EnqueueToBuffer()
                    {
                            for (int i = 0; i < currentCombination.Length; i++)
                            {
                                    consoleBuffer.Append(currentCombination[i].ToString());
                            }
                            consoleBuffer.AppendLine();
                    }
     
                    static void Main(string[] args)
                    {
                            DebugUtils.StartPerformanceDiagnostic();
                           
                            string[] input = GetInput();
                            possibleClockFaceDigits = new List<int[]>(input.Length);
                            currentCombination = new int[input.Length];
                            for (int i = 0; i < input.Length; i++)
                            {
                                    possibleClockFaceDigits.Add(GetDigitCombinations(input[i]));
                            }
     
                            EnumerateCombinations(0);
     
                            Console.WriteLine(nCombinations);
                            Console.Write(consoleBuffer);
     
                            DebugUtils.PrintPerformanceInfo();
                            DebugUtils.PrintPeakMemoryUsage();
                    }
            }
    }
