using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.IO;

namespace _6.Fire_and_Brimstone
{
	static class ExamExtensions
	{
		private static StreamReader inputFile;
		private static StreamReader InputFile
		{
			get
			{
				if (inputFile == null)
				{
					inputFile = new StreamReader("test2.txt");
				}

				return inputFile;
			}
		}
		
		public static bool Debugging
		{
			get
			{
#if DEBUG
				return true;
#else
				return false;
#endif
			}
		}

		public static int ToInt32(this string s)
		{
			return Convert.ToInt32(s);
		}

		public static double ToDouble(this string s)
		{
			return Convert.ToDouble(s);
		}

		public static string GetInput()
		{
			if (Debugging)
			{
				return InputFile.ReadLine();
			}
			else
			{
				return Console.ReadLine();
			}
		}
	}
	
	class Point
	{
		public double X { get; set; }
		public double Y { get; set; }

		public Point() :
			this(0, 0)
		{

		}

		public Point(double x, double y)
		{
			X = x;
			Y = y;
		}

		public Point(string s)
		{
			string[] split = s.Split(' ');
			X = split[0].ToDouble();
			Y = split[1].ToDouble();
		}

		public override string ToString()
		{
			return X + ":" + Y;
		}

		public override int GetHashCode()
		{
			return X.GetHashCode() ^ Y.GetHashCode();
		}
	}

	class LineSegment
	{
		public Point Start { get; set; }
		public Point End { get; set; }

		public LineSegment(Point start, Point end)
		{
			this.Start = start;
			this.End = end;
		}

		public override string ToString()
		{
			StringBuilder outputBuffer = new StringBuilder();
			outputBuffer.AppendFormat("{0}:{1}", Start.ToString(), End.ToString());
			return outputBuffer.ToString();
		}

		public void RotateAroundStart(double amount)
		{

		}

		public bool IntersectsWith(LineSegment other)
		{
			// The lines on which these segments lie intersect, if the denominator is non-zero
			double denominator = (other.End.Y - other.Start.Y) * (this.End.X - this.Start.X) -
				(other.End.X - other.Start.X) * (this.End.Y - this.Start.Y);
			if (denominator != 0)
			{
				double uA =
					((other.End.X - other.Start.X) * (this.Start.Y - other.Start.Y) -
					(other.End.Y - other.Start.Y) * (this.Start.X - other.Start.X)) / (double)denominator;
				double uB =
					((this.End.X - this.Start.X) * (this.Start.Y - other.Start.Y) -
					(this.End.Y - this.Start.Y) * (this.Start.X - other.Start.X)) / (double)denominator;

				return uA >= 0 && uA <= 1 && uB >= 0 && uB <= 1;
			}
			else
			{
				return false;
			}
		}
	}

	class Zerg
	{
		private List<LineSegment> contours;

		public Zerg(IEnumerable<Point> points)
		{
			contours = new List<LineSegment>();
			List<Point> buffer = new List<Point>();
			foreach (Point p in points)
			{
				buffer.Add(p);
				if (buffer.Count == 2)
				{
					contours.Add(new LineSegment(buffer[0], buffer[1]));
					buffer.Clear();
				}
			}
		}

		public bool ContainsPoint(Point p)
		{
			LineSegment randomRay = new LineSegment(p, new Point(1000000, 1000000));
			int randomRayIntersections = 0;
			foreach (LineSegment l in contours)
			{
				if (l.IntersectsWith(randomRay))
				{
					randomRayIntersections++;
				}
			}

			return (randomRayIntersections & 1) != 0;
		}

		public static List<Point> SortPoints(HashSet<Point> collection)
		{
			List<Point> t = new List<Point>();
			double lowestPoint = collection.Min(p => p.Y);
			Point startingPoint = collection.First(p => p.Y == lowestPoint);
			t.Add(startingPoint);
			var rightMostPoints = from points in collection
								  where points.X >= startingPoint.X
								  orderby points.Y
								  select points;
			t.AddRange(rightMostPoints);
			var leftMostPoints = from points in collection
								 where points.X < startingPoint.X
								 orderby points.Y descending
								 select points;
			t.AddRange(leftMostPoints);
			return t;
		}

		public static List<Point> SortPointsParallel(HashSet<Point> input)
		{
			var collection = input.AsParallel();
			List<Point> t = new List<Point>();
			double lowestPoint = collection.Min(p => p.Y);
			Point startingPoint = collection.First(p => p.Y == lowestPoint);
			t.Add(startingPoint);
			var rightMostPoints = from points in collection
								  where points.X >= startingPoint.X
								  orderby points.Y
								  select points;
			t.AddRange(rightMostPoints);
			var leftMostPoints = from points in collection
								 where points.X < startingPoint.X
								 orderby points.Y descending
								 select points;
			t.AddRange(leftMostPoints);
			return t;
		}
	}

	class Program
	{
		static List<Zerg> enemies;
		static List<Point> bullets;

		static Zerg ReadEnemyData(bool useParallelSorting = false)
		{
			int nPoints = ExamExtensions.GetInput().ToInt32();
			HashSet<Point> enemyCoords = new HashSet<Point>();
			for (int i = 0; i < nPoints; i++)
			{
				enemyCoords.Add(new Point(ExamExtensions.GetInput()));
			}

			Zerg result = new Zerg(useParallelSorting ? Zerg.SortPointsParallel(enemyCoords) : Zerg.SortPoints(enemyCoords));
			return result;
		}

		static void Main(string[] args)
		{
			string[] objData = ExamExtensions.GetInput().Split(' ');
			int nEnemies = objData[0].ToInt32();
			enemies = new List<Zerg>(nEnemies);
			for (int i = 0; i < nEnemies; i++)
			{
				enemies.Add(ReadEnemyData(nEnemies > 200));
			}

			int nBulletsFired = objData[1].ToInt32();
			bullets = new List<Point>(nBulletsFired);
			for (int i = 0; i < nBulletsFired; i++)
			{
				bullets.Add(new Point(ExamExtensions.GetInput()));
			}

			int nHits = 0;
			foreach (Zerg enemy in enemies)
			{
				foreach (Point bullet in bullets)
				{
					if (enemy.ContainsPoint(bullet))
					{
						nHits++;
						break;
					}
				 }
			}

			Console.WriteLine(nHits);
		}
	}
}
