#include<cstdio>
#include<vector>
#include<cmath>
#include<queue>

#define MAX(a,b) (((a) > (b)) ? (a) : (b))
using namespace std;

struct Edge
{
    double Value;
    int Node;

    bool operator< (const Edge& other) const
    {
        bool result = false;
        result = Value > other.Value;
        return result;
    }
};

const int encodeConstant = 501;
vector <int> graphNodes;
vector <Edge> graph[encodeConstant*encodeConstant];

int targetNodes = 0;
int ROWS,COLUMNS;
char map[encodeConstant][encodeConstant];

double chooseTower();
int BuildGraph();
double Prim(int startNode);
int Encode(int row, int column);
void Decode(int code, int* row, int* column);
double Distance(int X1, int Y1, int X2, int Y2);
bool IsTower(int node);
void ReadInput();

int main()
{
    ReadInput();
    printf("%lf\n",chooseTower());
    return 0;
}

void ReadInput()
{
    scanf("%d%d\n",&ROWS,&COLUMNS);
    for(int i=0; i<ROWS ;i++)
    {
        gets(map[i]);
    }
    return;
}

double chooseTower()
{
    int startNode = BuildGraph();
    double result = encodeConstant*encodeConstant*1.0;
    result = Prim(startNode);
    return result;
}

/// Performs Prim's algorithm
double Prim(int startNode)
{
    bool visitedNodes[encodeConstant*encodeConstant] = {0};
    visitedNodes[startNode] = true;
    double result = -1.0;
    int targetNodesFound = 0;

    priority_queue<Edge> priorityQueue;

    for(int i=0;i < graph[startNode].size(); i++)
    {
        Edge e = graph[startNode][i];
        priorityQueue.push(e);
    }

    while (targetNodes > targetNodesFound)
    {
        Edge edge = priorityQueue.top();
        priorityQueue.pop();

        if (!visitedNodes[edge.Node])
        {
            result = MAX(edge.Value, result);
            visitedNodes[edge.Node] = true;
            if (!IsTower(edge.Node))
            {
                targetNodesFound++;
            }
            if (graph[edge.Node].size() > 0)
            {
                for (int i=0; i < graph[edge.Node].size(); i++)
                {
                    Edge edge2 = graph[edge.Node][i];
                    priorityQueue.push(edge2);
                }
            }
        }
    }

    return result;
}

int BuildGraph()
{
    double minDistance = encodeConstant * encodeConstant * 1.0;
    int result = -1;
    targetNodes = 0;
    for (int row = 0; row < ROWS; row++)
    {
        for (int column = 0; column < COLUMNS; column++)
        {
            if (map[row][column] == '.')
            {
                continue;
            }
            if (map[row][column] == '*')
            {
                /// We are in tower node now.
                int currentNode = Encode(row, column);
                for (int i=0;i<graphNodes.size();i++)
                {
                    /// Add edges from the current node to all previously found nodes
                    int node = graphNodes[i];
                    int nodeX, nodeY;
                    Decode(node, &nodeX, &nodeY);
                    double distanceToNode = Distance(nodeX, nodeY, row, column);
                    Edge e;
                    e.Value = distanceToNode;
                    e.Node = node;

                    graph[currentNode].push_back(e);
                    if (IsTower(node))
                    {
                        /// Add the edge from the previously found node to the current one.
                        e.Node = currentNode;
                        graph[node].push_back(e);
                    }
                    else
                    {
                        if (minDistance > distanceToNode)
                        {
                            /// Get the tower, that is on minimal distance to any previously found target node.
                            minDistance = distanceToNode;
                            result = Encode(row, column);
                        }
                    }
                }
            }
            else
            {
                /// We are in target node now.
                for (int i=0;i < graphNodes.size();i++)
                {
                    /// Add edges from all prevoiusly found tower nodes to this one.
                    int previousNode = graphNodes[i];
                    if (IsTower(previousNode))
                    {
                        int nodeX, nodeY;
                        Decode(previousNode, &nodeX, &nodeY);
                        double distanceToNode = Distance(nodeX, nodeY, row, column);
                        Edge e;
                        e.Value = distanceToNode;
                        e.Node = Encode(row,column);
                        graph[previousNode].push_back(e);
                        if (minDistance > distanceToNode)
                        {
                            /// Get the tower, that is on minimal distance to any previously found target node.
                            minDistance = distanceToNode;
                            result = previousNode;
                        }
                    }
                }
                targetNodes++;
            }
            graphNodes.push_back(Encode(row, column));
        }
    }

    return result;
}

/// Checks if the node is tower or not.
bool IsTower(int node)
{
    int row, col;
    Decode(node, &row, &col);
    return map[row][col] == '*';
}

/// Encodes row and column into single node
int Encode(int row, int column)
{
    return row * encodeConstant + column;
}

/// Decodes the row and column, encoded in code
void Decode(int code, int* row, int* column)
{
    *row = code / encodeConstant;
    *column = code % encodeConstant;
}

double Distance(int X1, int Y1, int X2, int Y2) /// Gets the distance between points (X1,Y1) and (X2,Y2)
{
    double result = 0.0;
    result = sqrt(((X1 - X2) * (X1 - X2) + (Y1 - Y2) * (Y1 - Y2)) * 1.0);
    return result;
}
